set size ratio 1.3
set grid
set xrange [1/2.5:2.5]
set yrange [0.2:5]
set samples 2000
set parametric

set log x
set log y

set terminal pngcairo size 1000, 1200
set output "barbot-symmetric.png"

# solves the equation rho(s)q^2 - (s+1)q + 1 = 0
# (s^2 + cs + 1)q^2 - (s+1)q + 1 = q^2 s^2 + (cq - 1)qs + (q^2 - q + 1)
c = 2*cos(4*pi/5)
rho(s) = s**2 + c*s + 1
# qp(s) = (s+1+sqrt((s+1)**2 - 4*rho(s)))/(2*rho(s))
# qm(s) = (s+1-sqrt((s+1)**2 - 4*rho(s)))/(2*rho(s))
# d(q) = q**2*(c*q-1)**2 - 4*(q**2-q+1)*q**2
# sp(q) = (-(c*q-1)*q + sqrt(d(q)))/(2*q**2)
# sm(q) = (-(c*q-1)*q - sqrt(d(q)))/(2*q**2)
qp(s) = (s+1+sqrt((s+1)**2 - 4*rho(s)))/(2*sqrt(rho(s)))
qm(s) = (s+1-sqrt((s+1)**2 - 4*rho(s)))/(2*sqrt(rho(s)))
d(q) = q**2*(c*q-1)**2 - 4*(q**2-q+1)*q**2
sp(q) = (-(c*q-1)*q + sqrt(d(q)))/(2*q**2)
sm(q) = (-(c*q-1)*q - sqrt(d(q)))/(2*q**2)

plot "output/barbot_map_5000_frequencies" \
	 using ($1/100.0):($2/100.0*sqrt(rho($1/100.0))):(($3==0)?1/0:$4) w p pt 5 ps 0.5 lc palette t '', \
	 "output/barbot_map_500000"	\
	 using ($1/10.0) :($2/10.0*sqrt(rho($1/10.0))) :($3*0.7+0.3) w p pt 7 ps variable lc 3 t '', \
	 sm(t), d(t) > 0 ? t*sqrt(rho(sm(t))) : 1/0 w l lw 2 lc 7 t "", \
	 sp(t), d(t) > 0 ? t*sqrt(rho(sp(t))) : 1/0 w l lw 2 lc 7 t "", \
	 t, qm(t) w l lw 2 lc 7 t "", \
	 t, qp(t) w l lw 2 lc 7 t ""

# plot "output/barbot_map_50000_zoom_b" using ($1/1000.0):($2/5000):(($3==0)?1/0:$4) w p pt 5 ps 0.5 lc palette t ''

# pause mouse keypress
# reread
